@@ -4,7 +4,8 @@
 import pandas as pd
 import numpy as np
 from math import pi, cos, sin, sqrt
-
+import random
+import matplotlib.pyplot as plt
 import pkg_resources
 
 def load_aircraft_df():
@@ -71,7 +72,7 @@ def location(r1, r2, a1, a2, area, orientation='v', fill_angle=360.):
         out = r1, r2, a1, a3
     return out
 
-def pie_tree(df, groupers, r1, r2, start_angle, end_angle, points, default_sort = False, default_sort_override = True, default_sort_override_reversed = False, all_vertical = False):
+def pie_tree_calc(df, groupers, r1, r2, start_angle, end_angle, points, default_sort = False, default_sort_override = True, default_sort_override_reversed = False, all_vertical = False):
 
     #region algorithm
 
@@ -170,6 +171,29 @@ def pie_tree(df, groupers, r1, r2, start_angle, end_angle, points, default_sort
     df_out = pd.DataFrame.from_records([s.to_dict() for s in list_xy])
     return df_out
 
+def pie_tree_plot(pie_tree_df, level = 1, transparency = 0.5, line_level = 0):
+    fig, axs = plt.subplots()
+    axs.set_aspect('equal', adjustable='box')
+    df_lvl = pie_tree_df.loc[pie_tree_df['level'] == level]
+    df_lvl_group = df_lvl.groupby(['group'])
+    for group, rows in df_lvl_group:
+        x = rows['x'].values
+        y = rows['y'].values
+        r = random.random()
+        b = random.random()
+        g = random.random()
+        color = (r, g, b)
+        axs.fill(x, y, alpha=transparency, fc=color)
+        plt.plot(x, y, 'k-', linewidth=0.5)
+    if line_level > 0:
+        df_lvl = pie_tree_df.loc[pie_tree_df['level'] == line_level]
+        df_lvl_group = df_lvl.groupby(['group'])
+        for group, rows in df_lvl_group:
+            x = rows['x'].values
+            y = rows['y'].values
+            plt.plot(x, y, 'k-', linewidth=3)
+    plt.show()
+
 # df = pd.read_csv(os.path.dirname(__file__) + '/file.csv', dtype=pd.StringDtype())
 # groupers = ['column_1', 'column_2', 'column_n']
 # df_pie_tree = pie_tree(df, groupers, 0.5, 2., 0., 90., 200, default_sort = False, default_sort_override = True, default_sort_override_reversed = False, all_vertical = False)
\ No newline at end of file
